/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2014 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp14nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp14nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2771;
INPUT
   ACCEPT  1-2              BOOKER2  3               BOOKER3  4            
   BOOKERCD  5-6            BUSCLAS  7-10            CANTPAY  11           
   CCULPSCO  12-13          CH2APP  14               CH8FINGD  15          
   CMSRVORD  16             COFI  17                 COMPLY  18-19         
   COMPLYPR  20             CRIMPURP  21             DETBFINE  22          
   DISPOSIT  23             EMPLOYNM  24             FCULPSCO  25-26       
   FRAUDTYP  27-28          FINSTDS  29              HISTORY  30           
   HSMISCND  31             INCORLOC  32             INCORPYR  33-36       
   INDICT  37               INPLEA1  38              INPLEA2  39           
   INPLEA3  40              INPLEA4  41              INPLEA5  42           
   INPLEA6  43              INPLEA7  44              INPLEA8  45           
   INPLEA9  46              INPLEA10  47             INPLEA11  48          
   INPLEA12  49             INNOPL1  50              INNOPL2  51           
   INNOPL3  52              INNOPL4  53              INNOPL5  54           
   INNOPL6  55              INNOPL7  56              INNOPL8  57           
   INNOPL9  58              INNOPL10  59             INNOPL11  60          
   INNOPL12  61             JANDC  62                NEWCNVTN  63          
   NOCOMP  64               NOCOUNTS  65-66          NOREAVAR  67          
   NOUSTAT  68              OBSTRUCT  69             OFFLVL  70-71         
   ORDERCE  72              ORGTYPE  73              OWNSTRCT  74-75       
   PLEA  76                 PRIMOFF  77-78           PRCIVIL  79           
   PRCRIME  80              PROBATN  81-82           PROBMON  83           
   PSR  84                  QUARTER  85              REAS1  86-89          
   REAS2  90-92             REAS3  93-95             REAS4  96-98          
   REAS5  99                REASONS  100             REMEDORD  101         
   SELFREP  102             SOURCES  103             TOLERNCE  104         
   TYPEOTHS  105-106        VICTNOTE  107            VIOLATE  108          
   AMENDYR  109-112         SENTYR  113-116          BASEFINE  117-125     
   COSTASSM  126-128        DISGORGE  129            FINOFFST  130-135     
   FORFEITR  136-144        GLFINMAX  145-153        GLFINMIN  154-162     
   STATMIN  163-166         STATMAX  167-175         CPIDN  176-182        
   BUSTEXT $ 183-256        OWNSTEXT $ 257-321       FINSTXT $ 322-413     
   PRMONTXT $ 414-458       TYPEOTTX $ 459-658       ORDERTXT $ 659-758    
   MINFINML  759-761        MAXFINML  762-764        ADJOFL1  765-766      
   ADJOFL2  767-768         ADJOFL3  769-770         ADJOFLHI  771-772     
   ADJ_B1  773-774          ADJ_B2  775-776          ADJ_B3  777           
   ADJ_BHI  778-779         ADJ_C1  780-781          ADJ_C2  782           
   ADJ_C3  783              ADJ_CHI  784-785         ADJ_D1  786-788       
   ADJ_D2  789              ADJ_D3  790              ADJ_DHI  791-793      
   ADJ_E1  794              ADJ_E2  795              ADJ_E3  796           
   ADJ_EHI  797             ADJ_F1  798              ADJ_F2  799           
   ADJ_F3  800              ADJ_FHI  801             ADJ_G1  802           
   ADJ_G2  803              ADJ_G3  804              ADJ_GHI  805          
   ADJ_H1  806              ADJ_H2  807              ADJ_H3  808           
   ADJ_HHI  809             ADJ_I1  810              ADJ_I2  811           
   ADJ_I3  812              ADJ_IHI  813             ADJ_J1  814           
   ADJ_J2  815              ADJ_J3  816              ADJ_JHI  817          
   ADJ_K1  818              ADJ_K2  819              ADJ_K3  820           
   ADJ_KHI  821             ADJ_L1  822              ADJ_L2  823           
   ADJ_L3  824              ADJ_LHI  825             ADJ_M1  826           
   ADJ_M2  827              ADJ_M3  828              ADJ_MHI  829          
   ADJ_N1  830              ADJ_N2  831              ADJ_N3  832           
   ADJ_NHI  833             ADJ_O1  834              ADJ_O2  835           
   ADJ_O3  836              ADJ_OHI  837             ADJ_P1  838           
   ADJ_P2  839              ADJ_P3  840              ADJ_PHI  841          
   ADJ_Q1  842              ADJ_Q2  843              ADJ_Q3  844           
   ADJ_QHI  845             ADJ_R1  846              ADJ_R2  847           
   ADJ_R3  848              ADJ_RHI  849             ADJ_S1  850           
   ADJ_S2  851              ADJ_S3  852              ADJ_SHI  853          
   BASADJ1  854             BASADJ2  855             BASADJ3  856          
   BASADJHI  857            BASE1  858-859           BASE2  860            
   BASE3  861-862           BASEHI  863-864          BASLN1  865           
   BASLN2  866              BASLN3  867              BASLNHI  868          
   ADJOFR1  869-870         ADJOFR2  871-872         ADJOFR3  873          
   ADJOFRHI  874-875        ADJR_B1  876-877         ADJR_B2  878-879      
   ADJR_B3  880             ADJR_BHI  881-882        ADJR_C1  883-884      
   ADJR_C2  885             ADJR_C3  886             ADJR_CHI  887-888     
   ADJR_D1  889             ADJR_D2  890             ADJR_D3  891          
   ADJR_DHI  892            ADJR_E1  893             ADJR_E2  894          
   ADJR_E3  895             ADJR_EHI  896            ADJR_F1  897          
   ADJR_F2  898             ADJR_F3  899             ADJR_FHI  900         
   ADJR_G1  901             ADJR_G2  902             ADJR_G3  903          
   ADJR_GHI  904            ADJR_H1  905             ADJR_H2  906          
   ADJR_H3  907             ADJR_HHI  908            ADJR_I1  909          
   ADJR_I2  910             ADJR_I3  911             ADJR_IHI  912         
   ADJR_J1  913             ADJR_J2  914             ADJR_J3  915          
   ADJR_JHI  916            ADJR_K1  917             ADJR_K2  918          
   ADJR_K3  919             ADJR_KHI  920            ADJR_L1  921          
   ADJR_L2  922             ADJR_L3  923             ADJR_LHI  924         
   ADJR_M1  925             ADJR_M2  926             ADJR_M3  927          
   ADJR_MHI  928            ADJR_N1  929             ADJR_N2  930          
   ADJR_N3  931             ADJR_NHI  932            ADJR_O1  933          
   ADJR_O2  934             ADJR_O3  935             ADJR_OHI  936         
   ADJR_P1  937             ADJR_P2  938             ADJR_P3  939          
   ADJR_PHI  940            ADJR_Q1  941             ADJR_Q2  942          
   ADJR_Q3  943             ADJR_QHI  944            ADJR_R1  945          
   ADJR_R2  946             ADJR_R3  947             ADJR_RHI  948         
   ADJR_S1  949             ADJR_S2  950             ADJR_S3  951          
   ADJR_SHI  952            BASADR1  953             BASADR2  954          
   BASADR3  955             BASADRHI  956            BASER1  957-958       
   BASER2  959              BASER3  960              BASERHI  961-962      
   BASLNR1  963             BASLNR2  964             BASLNR3  965          
   BASLNRHI  966            ADJOFS1  967-968         ADJOFS2  969-970      
   ADJOFS3  971-972         ADJOFSHI  973-974        ADJS_B1  975-976      
   ADJS_B2  977-978         ADJS_B3  979             ADJS_BHI  980-981     
   ADJS_C1  982-983         ADJS_C2  984             ADJS_C3  985          
   ADJS_CHI  986-987        ADJS_D1  988-990         ADJS_D2  991          
   ADJS_D3  992             ADJS_DHI  993-995        ADJS_E1  996          
   ADJS_E2  997             ADJS_E3  998             ADJS_EHI  999         
   ADJS_F1  1000            ADJS_F2  1001            ADJS_F3  1002         
   ADJS_FHI  1003           ADJS_G1  1004            ADJS_G2  1005         
   ADJS_G3  1006            ADJS_GHI  1007           ADJS_H1  1008         
   ADJS_H2  1009            ADJS_H3  1010            ADJS_HHI  1011        
   ADJS_I1  1012            ADJS_I2  1013            ADJS_I3  1014         
   ADJS_IHI  1015           ADJS_J1  1016            ADJS_J2  1017         
   ADJS_J3  1018            ADJS_JHI  1019           ADJS_K1  1020         
   ADJS_K2  1021            ADJS_K3  1022            ADJS_KHI  1023        
   ADJS_L1  1024            ADJS_L2  1025            ADJS_L3  1026         
   ADJS_LHI  1027           ADJS_M1  1028            ADJS_M2  1029         
   ADJS_M3  1030            ADJS_MHI  1031           ADJS_N1  1032         
   ADJS_N2  1033            ADJS_N3  1034            ADJS_NHI  1035        
   ADJS_O1  1036            ADJS_O2  1037            ADJS_O3  1038         
   ADJS_OHI  1039           ADJS_P1  1040            ADJS_P2  1041         
   ADJS_P3  1042            ADJS_PHI  1043           ADJS_Q1  1044         
   ADJS_Q2  1045            ADJS_Q3  1046            ADJS_QHI  1047        
   ADJS_R1  1048            ADJS_R2  1049            ADJS_R3  1050         
   ADJS_RHI  1051           ADJS_S1  1052            ADJS_S2  1053         
   ADJS_S3  1054            ADJS_SHI  1055           BASADS1  1056         
   BASADS2  1057            BASADS3  1058            BASADSHI  1059        
   BASES1  1060-1061        BASES2  1062             BASES3  1063-1064     
   BASESHI  1065-1066       BASLNS1  1067            BASLNS2  1068         
   BASLNS3  1069            BASLNSHI  1070           ADJOFC1  1071-1072    
   ADJOFC2  1073            ADJOFC3  1074            ADJOFCHI  1075-1076   
   ADJC_B1  1077-1078       ADJC_B2  1079            ADJC_B3  1080         
   ADJC_BHI  1081-1082      ADJC_C1  1083            ADJC_C2  1084         
   ADJC_C3  1085            ADJC_CHI  1086           ADJC_D1  1087         
   ADJC_D2  1088            ADJC_D3  1089            ADJC_DHI  1090        
   ADJC_E1  1091            ADJC_E2  1092            ADJC_E3  1093         
   ADJC_EHI  1094           ADJC_F1  1095            ADJC_F2  1096         
   ADJC_F3  1097            ADJC_FHI  1098           ADJC_G1  1099         
   ADJC_G2  1100            ADJC_G3  1101            ADJC_GHI  1102        
   ADJC_H1  1103            ADJC_H2  1104            ADJC_H3  1105         
   ADJC_HHI  1106           ADJC_I1  1107            ADJC_I2  1108         
   ADJC_I3  1109            ADJC_IHI  1110           ADJC_J1  1111         
   ADJC_J2  1112            ADJC_J3  1113            ADJC_JHI  1114        
   ADJC_K1  1115            ADJC_K2  1116            ADJC_K3  1117         
   ADJC_KHI  1118           ADJC_L1  1119            ADJC_L2  1120         
   ADJC_L3  1121            ADJC_LHI  1122           ADJC_M1  1123         
   ADJC_M2  1124            ADJC_M3  1125            ADJC_MHI  1126        
   ADJC_N1  1127            ADJC_N2  1128            ADJC_N3  1129         
   ADJC_NHI  1130           ADJC_O1  1131            ADJC_O2  1132         
   ADJC_O3  1133            ADJC_OHI  1134           ADJC_P1  1135         
   ADJC_P2  1136            ADJC_P3  1137            ADJC_PHI  1138        
   ADJC_Q1  1139            ADJC_Q2  1140            ADJC_Q3  1141         
   ADJC_QHI  1142           ADJC_R1  1143            ADJC_R2  1144         
   ADJC_R3  1145            ADJC_RHI  1146           ADJC_S1  1147         
   ADJC_S2  1148            ADJC_S3  1149            ADJC_SHI  1150        
   BASADC1  1151            BASADC2  1152            BASADC3  1153         
   BASADCHI  1154           BASEC1  1155             BASEC2  1156          
   BASEC3  1157             BASECHI  1158            BASLNC1  1159         
   BASLNC2  1160            BASLNC3  1161            BASLNCHI  1162        
   ADJOFU1  1163            ADJOFU2  1164            ADJOFU3  1165         
   ADJOFUHI  1166           ADJU_B1  1167            ADJU_B2  1168         
   ADJU_B3  1169            ADJU_BHI  1170           ADJU_C1  1171         
   ADJU_C2  1172            ADJU_C3  1173            ADJU_CHI  1174        
   ADJU_D1  1175            ADJU_D2  1176            ADJU_D3  1177         
   ADJU_DHI  1178           ADJU_E1  1179            ADJU_E2  1180         
   ADJU_E3  1181            ADJU_EHI  1182           ADJU_F1  1183         
   ADJU_F2  1184            ADJU_F3  1185            ADJU_FHI  1186        
   ADJU_G1  1187            ADJU_G2  1188            ADJU_G3  1189         
   ADJU_GHI  1190           ADJU_H1  1191            ADJU_H2  1192         
   ADJU_H3  1193            ADJU_HHI  1194           ADJU_I1  1195         
   ADJU_I2  1196            ADJU_I3  1197            ADJU_IHI  1198        
   ADJU_J1  1199            ADJU_J2  1200            ADJU_J3  1201         
   ADJU_JHI  1202           ADJU_K1  1203            ADJU_K2  1204         
   ADJU_K3  1205            ADJU_KHI  1206           ADJU_L1  1207         
   ADJU_L2  1208            ADJU_L3  1209            ADJU_LHI  1210        
   ADJU_M1  1211            ADJU_M2  1212            ADJU_M3  1213         
   ADJU_MHI  1214           ADJU_N1  1215            ADJU_N2  1216         
   ADJU_N3  1217            ADJU_NHI  1218           ADJU_O1  1219         
   ADJU_O2  1220            ADJU_O3  1221            ADJU_OHI  1222        
   ADJU_P1  1223            ADJU_P2  1224            ADJU_P3  1225         
   ADJU_PHI  1226           ADJU_Q1  1227            ADJU_Q2  1228         
   ADJU_Q3  1229            ADJU_QHI  1230           ADJU_R1  1231         
   ADJU_R2  1232            ADJU_R3  1233            ADJU_RHI  1234        
   ADJU_S1  1235            ADJU_S2  1236            ADJU_S3  1237         
   ADJU_SHI  1238           BASADU1  1239            BASADU2  1240         
   BASADU3  1241            BASADUHI  1242           BASEU1  1243          
   BASEU2  1244             BASEU3  1245             BASEUHI  1246         
   BASLNU1  1247            BASLNU2  1248            BASLNU3  1249         
   BASLNUHI  1250           ADJL_B1 $ 1251           ADJL_B2 $ 1252        
   ADJL_B3 $ 1253           ADJL_BHI $ 1254          ADJL_C1 $ 1255-1256   
   ADJL_C2 $ 1257-1258      ADJL_C3 $ 1259           ADJL_CHI $ 1260-1261  
   ADJL_D1 $ 1262           ADJL_D2 $ 1263           ADJL_D3 $ 1264        
   ADJL_DHI $ 1265          ADJL_E1 $ 1266           ADJL_E2 $ 1267        
   ADJL_E3 $ 1268           ADJL_EHI $ 1269          ADJL_F1 $ 1270        
   ADJL_F2 $ 1271           ADJL_F3 $ 1272           ADJL_FHI $ 1273       
   ADJL_G1 $ 1274           ADJL_G2 $ 1275           ADJL_G3 $ 1276        
   ADJL_GHI $ 1277          ADJL_H1 $ 1278-1279      ADJL_H2 $ 1280        
   ADJL_H3 $ 1281           ADJL_HHI $ 1282-1283     ADJL_I1 $ 1284-1285   
   ADJL_I2 $ 1286           ADJL_I3 $ 1287           ADJL_IHI $ 1288-1289  
   ADJL_J1 $ 1290           ADJL_J2 $ 1291           ADJL_J3 $ 1292        
   ADJL_JHI $ 1293          ADJL_K1 $ 1294           ADJL_K2 $ 1295        
   ADJL_K3 $ 1296           ADJL_KHI $ 1297          ADJL_L1 $ 1298        
   ADJL_L2 $ 1299           ADJL_L3 $ 1300           ADJL_LHI $ 1301       
   ADJL_M1 $ 1302           ADJL_M2 $ 1303           ADJL_M3 $ 1304        
   ADJL_MHI $ 1305          ADJL_N1 $ 1306           ADJL_N2 $ 1307        
   ADJL_N3 $ 1308           ADJL_NHI $ 1309          ADJL_O1 $ 1310        
   ADJL_O2 $ 1311           ADJL_O3 $ 1312           ADJL_OHI $ 1313       
   ADJL_P1 $ 1314           ADJL_P2 $ 1315           ADJL_P3 $ 1316        
   ADJL_PHI $ 1317          ADJL_Q1 $ 1318           ADJL_Q2 $ 1319        
   ADJL_Q3 $ 1320           ADJL_QHI $ 1321          ADJL_R1 $ 1322        
   ADJL_R2 $ 1323           ADJL_R3 $ 1324           ADJL_RHI $ 1325       
   ADJL_S1 $ 1326           ADJL_S2 $ 1327           ADJL_S3 $ 1328        
   ADJL_SHI $ 1329          BASEL1 $ 1330            BASEL2 $ 1331         
   BASEL3 $ 1332            BASELHI $ 1333           ADRL_B1 $ 1334        
   ADRL_B2 $ 1335           ADRL_B3 $ 1336           ADRL_BHI $ 1337       
   ADRL_C1 $ 1338           ADRL_C2 $ 1339           ADRL_C3 $ 1340        
   ADRL_CHI $ 1341          ADRL_D1 $ 1342           ADRL_D2 $ 1343        
   ADRL_D3 $ 1344           ADRL_DHI $ 1345          ADRL_E1 $ 1346        
   ADRL_E2 $ 1347           ADRL_E3 $ 1348           ADRL_EHI $ 1349       
   ADRL_F1 $ 1350           ADRL_F2 $ 1351           ADRL_F3 $ 1352        
   ADRL_FHI $ 1353          ADRL_G1 $ 1354           ADRL_G2 $ 1355        
   ADRL_G3 $ 1356           ADRL_GHI $ 1357          ADRL_H1 $ 1358        
   ADRL_H2 $ 1359           ADRL_H3 $ 1360           ADRL_HHI $ 1361       
   ADRL_I1 $ 1362           ADRL_I2 $ 1363           ADRL_I3 $ 1364        
   ADRL_IHI $ 1365          ADRL_J1 $ 1366           ADRL_J2 $ 1367        
   ADRL_J3 $ 1368           ADRL_JHI $ 1369          ADRL_K1 $ 1370        
   ADRL_K2 $ 1371           ADRL_K3 $ 1372           ADRL_KHI $ 1373       
   ADRL_L1 $ 1374           ADRL_L2 $ 1375           ADRL_L3 $ 1376        
   ADRL_LHI $ 1377          ADRL_M1 $ 1378           ADRL_M2 $ 1379        
   ADRL_M3 $ 1380           ADRL_MHI $ 1381          ADRL_N1 $ 1382        
   ADRL_N2 $ 1383           ADRL_N3 $ 1384           ADRL_NHI $ 1385       
   ADRL_O1 $ 1386           ADRL_O2 $ 1387           ADRL_O3 $ 1388        
   ADRL_OHI $ 1389          ADRL_P1 $ 1390           ADRL_P2 $ 1391        
   ADRL_P3 $ 1392           ADRL_PHI $ 1393          ADRL_Q1 $ 1394        
   ADRL_Q2 $ 1395           ADRL_Q3 $ 1396           ADRL_QHI $ 1397       
   ADRL_R1 $ 1398           ADRL_R2 $ 1399           ADRL_R3 $ 1400        
   ADRL_RHI $ 1401          ADRL_S1 $ 1402           ADRL_S2 $ 1403        
   ADRL_S3 $ 1404           ADRL_SHI $ 1405          BASERL1 $ 1406        
   BASERL2 $ 1407           BASERL3 $ 1408           BASERLHI $ 1409       
   ADSL_B1 $ 1410           ADSL_B2 $ 1411           ADSL_B3 $ 1412        
   ADSL_BHI $ 1413          ADSL_C1 $ 1414-1415      ADSL_C2 $ 1416-1417   
   ADSL_C3 $ 1418           ADSL_CHI $ 1419-1420     ADSL_D1 $ 1421        
   ADSL_D2 $ 1422           ADSL_D3 $ 1423           ADSL_DHI $ 1424       
   ADSL_E1 $ 1425           ADSL_E2 $ 1426           ADSL_E3 $ 1427        
   ADSL_EHI $ 1428          ADSL_F1 $ 1429           ADSL_F2 $ 1430        
   ADSL_F3 $ 1431           ADSL_FHI $ 1432          ADSL_G1 $ 1433        
   ADSL_G2 $ 1434           ADSL_G3 $ 1435           ADSL_GHI $ 1436       
   ADSL_H1 $ 1437-1438      ADSL_H2 $ 1439           ADSL_H3 $ 1440        
   ADSL_HHI $ 1441-1442     ADSL_I1 $ 1443-1444      ADSL_I2 $ 1445        
   ADSL_I3 $ 1446           ADSL_IHI $ 1447-1448     ADSL_J1 $ 1449        
   ADSL_J2 $ 1450           ADSL_J3 $ 1451           ADSL_JHI $ 1452       
   ADSL_K1 $ 1453           ADSL_K2 $ 1454           ADSL_K3 $ 1455        
   ADSL_KHI $ 1456          ADSL_L1 $ 1457           ADSL_L2 $ 1458        
   ADSL_L3 $ 1459           ADSL_LHI $ 1460          ADSL_M1 $ 1461        
   ADSL_M2 $ 1462           ADSL_M3 $ 1463           ADSL_MHI $ 1464       
   ADSL_N1 $ 1465           ADSL_N2 $ 1466           ADSL_N3 $ 1467        
   ADSL_NHI $ 1468          ADSL_O1 $ 1469           ADSL_O2 $ 1470        
   ADSL_O3 $ 1471           ADSL_OHI $ 1472          ADSL_P1 $ 1473        
   ADSL_P2 $ 1474           ADSL_P3 $ 1475           ADSL_PHI $ 1476       
   ADSL_Q1 $ 1477           ADSL_Q2 $ 1478           ADSL_Q3 $ 1479        
   ADSL_QHI $ 1480          ADSL_R1 $ 1481           ADSL_R2 $ 1482        
   ADSL_R3 $ 1483           ADSL_RHI $ 1484          ADSL_S1 $ 1485        
   ADSL_S2 $ 1486           ADSL_S3 $ 1487           ADSL_SHI $ 1488       
   BASESL1 $ 1489           BASESL2 $ 1490           BASESL3 $ 1491        
   BASESLHI $ 1492          ADCL_B1 $ 1493           ADCL_B2 $ 1494        
   ADCL_B3 $ 1495           ADCL_BHI $ 1496          ADCL_C1 $ 1497-1498   
   ADCL_C2 $ 1499           ADCL_C3 $ 1500           ADCL_CHI $ 1501-1502  
   ADCL_D1 $ 1503           ADCL_D2 $ 1504           ADCL_D3 $ 1505        
   ADCL_DHI $ 1506          ADCL_E1 $ 1507           ADCL_E2 $ 1508        
   ADCL_E3 $ 1509           ADCL_EHI $ 1510          ADCL_F1 $ 1511        
   ADCL_F2 $ 1512           ADCL_F3 $ 1513           ADCL_FHI $ 1514       
   ADCL_G1 $ 1515           ADCL_G2 $ 1516           ADCL_G3 $ 1517        
   ADCL_GHI $ 1518          ADCL_H1 $ 1519           ADCL_H2 $ 1520        
   ADCL_H3 $ 1521           ADCL_HHI $ 1522          ADCL_I1 $ 1523        
   ADCL_I2 $ 1524           ADCL_I3 $ 1525           ADCL_IHI $ 1526       
   ADCL_J1 $ 1527           ADCL_J2 $ 1528           ADCL_J3 $ 1529        
   ADCL_JHI $ 1530          ADCL_K1 $ 1531           ADCL_K2 $ 1532        
   ADCL_K3 $ 1533           ADCL_KHI $ 1534          ADCL_L1 $ 1535        
   ADCL_L2 $ 1536           ADCL_L3 $ 1537           ADCL_LHI $ 1538       
   ADCL_M1 $ 1539           ADCL_M2 $ 1540           ADCL_M3 $ 1541        
   ADCL_MHI $ 1542          ADCL_N1 $ 1543           ADCL_N2 $ 1544        
   ADCL_N3 $ 1545           ADCL_NHI $ 1546          ADCL_O1 $ 1547        
   ADCL_O2 $ 1548           ADCL_O3 $ 1549           ADCL_OHI $ 1550       
   ADCL_P1 $ 1551           ADCL_P2 $ 1552           ADCL_P3 $ 1553        
   ADCL_PHI $ 1554          ADCL_Q1 $ 1555           ADCL_Q2 $ 1556        
   ADCL_Q3 $ 1557           ADCL_QHI $ 1558          ADCL_R1 $ 1559        
   ADCL_R2 $ 1560           ADCL_R3 $ 1561           ADCL_RHI $ 1562       
   ADCL_S1 $ 1563           ADCL_S2 $ 1564           ADCL_S3 $ 1565        
   ADCL_SHI $ 1566          BASECL1 $ 1567           BASECL2 $ 1568        
   BASECL3 $ 1569           BASECLHI $ 1570          ADUL_B1 $ 1571        
   ADUL_B2 $ 1572           ADUL_B3 $ 1573           ADUL_BHI $ 1574       
   ADUL_C1 $ 1575           ADUL_C2 $ 1576           ADUL_C3 $ 1577        
   ADUL_CHI $ 1578          ADUL_D1 $ 1579           ADUL_D2 $ 1580        
   ADUL_D3 $ 1581           ADUL_DHI $ 1582          ADUL_E1 $ 1583        
   ADUL_E2 $ 1584           ADUL_E3 $ 1585           ADUL_EHI $ 1586       
   ADUL_F1 $ 1587           ADUL_F2 $ 1588           ADUL_F3 $ 1589        
   ADUL_FHI $ 1590          ADUL_G1 $ 1591           ADUL_G2 $ 1592        
   ADUL_G3 $ 1593           ADUL_GHI $ 1594          ADUL_H1 $ 1595        
   ADUL_H2 $ 1596           ADUL_H3 $ 1597           ADUL_HHI $ 1598       
   ADUL_I1 $ 1599           ADUL_I2 $ 1600           ADUL_I3 $ 1601        
   ADUL_IHI $ 1602          ADUL_J1 $ 1603           ADUL_J2 $ 1604        
   ADUL_J3 $ 1605           ADUL_JHI $ 1606          ADUL_K1 $ 1607        
   ADUL_K2 $ 1608           ADUL_K3 $ 1609           ADUL_KHI $ 1610       
   ADUL_L1 $ 1611           ADUL_L2 $ 1612           ADUL_L3 $ 1613        
   ADUL_LHI $ 1614          ADUL_M1 $ 1615           ADUL_M2 $ 1616        
   ADUL_M3 $ 1617           ADUL_MHI $ 1618          ADUL_N1 $ 1619        
   ADUL_N2 $ 1620           ADUL_N3 $ 1621           ADUL_NHI $ 1622       
   ADUL_O1 $ 1623           ADUL_O2 $ 1624           ADUL_O3 $ 1625        
   ADUL_OHI $ 1626          ADUL_P1 $ 1627           ADUL_P2 $ 1628        
   ADUL_P3 $ 1629           ADUL_PHI $ 1630          ADUL_Q1 $ 1631        
   ADUL_Q2 $ 1632           ADUL_Q3 $ 1633           ADUL_QHI $ 1634       
   ADUL_R1 $ 1635           ADUL_R2 $ 1636           ADUL_R3 $ 1637        
   ADUL_RHI $ 1638          ADUL_S1 $ 1639           ADUL_S2 $ 1640        
   ADUL_S3 $ 1641           ADUL_SHI $ 1642          BASEUL1 $ 1643        
   BASEUL2 $ 1644           BASEUL3 $ 1645           BASEULHI $ 1646       
   GDLINE1 $ 1647-1651      GDLINE2 $ 1652-1656      GDLINE3 $ 1657-1661   
   GDSTAT1 $ 1662-1666      GDSTAT2 $ 1667-1671      GDSTAT3 $ 1672-1676   
   GDREF1 $ 1677-1681       GDREF2 $ 1682-1686       GDREF3 $ 1687         
   GDCROS1 $ 1688-1692      GDCROS2 $ 1693           GDCROS3 $ 1694        
   GDUNDR1 $ 1695           GDUNDR2 $ 1696           GDUNDR3 $ 1697        
   GDLINEHI $ 1698-1702     GDSTATHI $ 1703-1707     GDREFHI $ 1708-1712   
   GDCROSHI $ 1713-1717     GDUNDRHI $ 1718          STA1_1 $ 1719-1728    
   STA1_2 $ 1729-1739       STA1_3 $ 1740-1748       STA1_4 $ 1749-1756    
   STA1_5 $ 1757-1764       STA1_6 $ 1765-1772       STA1_7 $ 1773-1782    
   STA1_8 $ 1783-1790       STA1_9 $ 1791-1798       STA1_10 $ 1799-1808   
   STA1_11 $ 1809-1817      STA1_12 $ 1818-1826      STA1_13 $ 1827-1836   
   STA1_14 $ 1837-1846      STA1_15 $ 1847-1853      STA1_16 $ 1854-1860   
   STA1_17 $ 1861-1867      STA1_18 $ 1868-1874      STA1_19 $ 1875-1881   
   STA1_20 $ 1882-1888      STA1_21 $ 1889-1895      STA1_22 $ 1896-1902   
   STA1_23 $ 1903-1909      STA1_24 $ 1910-1916      STA1_25 $ 1917-1923   
   STA1_26 $ 1924-1929      STA1_27 $ 1930-1935      STA1_28 $ 1936-1941   
   STA1_29 $ 1942-1947      STA1_30 $ 1948-1953      STA1_31 $ 1954-1959   
   STA1_32 $ 1960-1967      STA2_1 $ 1968-1978       STA2_2 $ 1979-1987    
   STA2_3 $ 1988-1996       STA2_4 $ 1997-2005       STA2_5 $ 2006-2014    
   STA2_6 $ 2015-2023       STA2_7 $ 2024-2032       STA2_8 $ 2033-2041    
   STA2_9 $ 2042-2050       STA2_10 $ 2051-2059      STA2_11 $ 2060-2068   
   STA2_12 $ 2069-2077      STA2_13 $ 2078-2087      STA2_14 $ 2088-2097   
   STA2_15 $ 2098-2106      STA2_16 $ 2107-2115      STA2_17 $ 2116-2124   
   STA2_18 $ 2125-2133      STA2_19 $ 2134-2142      STA2_20 $ 2143-2151   
   STA2_21 $ 2152-2160      STA2_22 $ 2161-2169      STA2_23 $ 2170-2178   
   STA2_24 $ 2179-2187      STA2_25 $ 2188-2196      STA2_26 $ 2197-2199   
   STA2_27 $ 2200-2202      STA2_28 $ 2203-2205      STA2_29 $ 2206-2208   
   STA2_30 $ 2209-2211      STA2_31 $ 2212-2214      STA2_32 $ 2215        
   STA3_1 $ 2216-2225       STA3_2 $ 2226-2234       STA3_3 $ 2235-2243    
   STA3_4 $ 2244-2252       STA3_5 $ 2253-2255       STA3_6 $ 2256-2258    
   STA3_7 $ 2259-2261       STA3_8 $ 2262-2269       STA3_9 $ 2270-2277    
   STA3_10 $ 2278-2285      STA3_11 $ 2286-2293      STA3_12 $ 2294-2301   
   STA3_13 $ 2302           STA3_14 $ 2303           STA3_15 $ 2304        
   STA3_16 $ 2305           STA3_17 $ 2306           STA3_18 $ 2307        
   STA3_19 $ 2308           STA3_20 $ 2309           STA3_21 $ 2310        
   STA3_22 $ 2311           STA3_23 $ 2312           STA3_24 $ 2313        
   STA3_25 $ 2314           STA3_26 $ 2315           STA3_27 $ 2316        
   STA3_28 $ 2317           STA3_29 $ 2318           STA3_30 $ 2319        
   STA3_31 $ 2320           STA3_32 $ 2321           NWSTAT1 $ 2322-2331   
   NWSTAT2 $ 2332-2342      NWSTAT3 $ 2343-2352      NWSTAT4 $ 2353-2362   
   NWSTAT5 $ 2363-2372      NWSTAT6 $ 2373-2381      NWSTAT7 $ 2382-2391   
   NWSTAT8 $ 2392-2398      SMAX1  2399-2407         SMAX2  2408-2416      
   SMAX3  2417-2425         SMAX4  2426-2433         SMAX5  2434-2441      
   SMAX6  2442-2449         SMAX7  2450-2457         SMAX8  2458-2465      
   SMAX9  2466-2471         SMAX10  2472-2478        SMAX11  2479-2484     
   SMAX12  2485-2490        SMAX13  2491-2496        SMAX14  2497-2502     
   SMAX15  2503-2508        SMAX16  2509-2514        SMAX17  2515-2520     
   SMAX18  2521-2526        SMAX19  2527-2532        SMAX20  2533-2538     
   SMAX21  2539-2544        SMAX22  2545-2550        SMAX23  2551-2556     
   SMAX24  2557-2562        SMAX25  2563-2568        SMAX26  2569-2574     
   SMAX27  2575-2580        SMAX28  2581-2586        SMAX29  2587-2592     
   SMAX30  2593-2598        SMAX31  2599-2604        SMAX32  2605-2609     
   SMIN1  2610-2613         SMIN2  2614-2617         SMIN3  2618-2621      
   SMIN4  2622-2625         SMIN5  2626-2629         SMIN6  2630-2633      
   SMIN7  2634-2637         SMIN8  2638-2641         SMIN9  2642-2645      
   SMIN10  2646-2649        SMIN11  2650-2653        SMIN12  2654-2657     
   SMIN13  2658-2661        SMIN14  2662-2665        SMIN15  2666-2669     
   SMIN16  2670-2673        SMIN17  2674-2677        SMIN18  2678-2681     
   SMIN19  2682-2685        SMIN20  2686-2689        SMIN21  2690-2693     
   SMIN22  2694-2697        SMIN23  2698-2701        SMIN24  2702-2705     
   SMIN25  2706-2709        SMIN26  2710             SMIN27  2711          
   SMIN28  2712             SMIN29  2713             SMIN30  2714          
   SMIN31  2715             SMIN32  2716             RETEXT1 $ 2717-2744   
   RETEXT2 $ 2745           RETEXT3 $ 2746           RETEXT4 $ 2747        
   RETEXT5 $ 2748           RESTCAT  2749            FINECAT  2750         
   SUSFNCAT  2751           LCAT1  2752              LCAT2  2753           
   LCAT3  2754              LCATHI  2755             LCATS1  2756          
   LCATS2  2757             LCATS3  2758             LCATSHI  2759         
   LCATR1  2760             LCATR2  2761             LCATR3  2762          
   LCATRHI  2763            LCATC1  2764             LCATC2  2765          
   LCATC3  2766             LCATCHI  2767            LCATU1  2768          
   LCATU2  2769             LCATU3  2770             LCATUHI  2771         
 ;                       

LENGTH
   ACCEPT 3                 BOOKER2 3                BOOKER3 3             
   BOOKERCD 3               BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 4                  REAS4 4               
   REAS5 3                  REASONS 3                REMEDORD 3            
   SELFREP 3                SOURCES 3                TOLERNCE 3            
   TYPEOTHS 3               VICTNOTE 3               VIOLATE 3             
   AMENDYR 4                SENTYR 4                 BASEFINE 6            
   COSTASSM 4               DISGORGE 3               FINOFFST 6            
   FORFEITR 6               GLFINMAX 6               GLFINMIN 6            
   STATMIN 4                STATMAX 6                CPIDN 6               
   ADJOFL1 3                ADJOFL2 3                ADJOFL3 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_B3 3                 ADJ_BHI 3                ADJ_C1 3              
   ADJ_C2 3                 ADJ_C3 3                 ADJ_CHI 3             
   ADJ_D1 3                 ADJ_D2 3                 ADJ_D3 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_E3 3                 ADJ_EHI 3                ADJ_F1 3              
   ADJ_F2 3                 ADJ_F3 3                 ADJ_FHI 3             
   ADJ_G1 3                 ADJ_G2 3                 ADJ_G3 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_H3 3                 ADJ_HHI 3                ADJ_I1 3              
   ADJ_I2 3                 ADJ_I3 3                 ADJ_IHI 3             
   ADJ_J1 3                 ADJ_J2 3                 ADJ_J3 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_K3 3                 ADJ_KHI 3                ADJ_L1 3              
   ADJ_L2 3                 ADJ_L3 3                 ADJ_LHI 3             
   ADJ_M1 3                 ADJ_M2 3                 ADJ_M3 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_N3 3                 ADJ_NHI 3                ADJ_O1 3              
   ADJ_O2 3                 ADJ_O3 3                 ADJ_OHI 3             
   ADJ_P1 3                 ADJ_P2 3                 ADJ_P3 3              
   ADJ_PHI 3                ADJ_Q1 3                 ADJ_Q2 3              
   ADJ_Q3 3                 ADJ_QHI 3                ADJ_R1 3              
   ADJ_R2 3                 ADJ_R3 3                 ADJ_RHI 3             
   ADJ_S1 3                 ADJ_S2 3                 ADJ_S3 3              
   ADJ_SHI 3                BASADJ1 3                BASADJ2 3             
   BASADJ3 3                BASADJHI 3               BASE1 3               
   BASE2 3                  BASE3 3                  BASEHI 3              
   BASLN1 3                 BASLN2 3                 BASLN3 3              
   BASLNHI 3                ADJOFR1 3                ADJOFR2 3             
   ADJOFR3 3                ADJOFRHI 3               ADJR_B1 3             
   ADJR_B2 3                ADJR_B3 3                ADJR_BHI 3            
   ADJR_C1 3                ADJR_C2 3                ADJR_C3 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_D3 3                ADJR_DHI 3               ADJR_E1 3             
   ADJR_E2 3                ADJR_E3 3                ADJR_EHI 3            
   ADJR_F1 3                ADJR_F2 3                ADJR_F3 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_G3 3                ADJR_GHI 3               ADJR_H1 3             
   ADJR_H2 3                ADJR_H3 3                ADJR_HHI 3            
   ADJR_I1 3                ADJR_I2 3                ADJR_I3 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_J3 3                ADJR_JHI 3               ADJR_K1 3             
   ADJR_K2 3                ADJR_K3 3                ADJR_KHI 3            
   ADJR_L1 3                ADJR_L2 3                ADJR_L3 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_M3 3                ADJR_MHI 3               ADJR_N1 3             
   ADJR_N2 3                ADJR_N3 3                ADJR_NHI 3            
   ADJR_O1 3                ADJR_O2 3                ADJR_O3 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_P3 3                ADJR_PHI 3               ADJR_Q1 3             
   ADJR_Q2 3                ADJR_Q3 3                ADJR_QHI 3            
   ADJR_R1 3                ADJR_R2 3                ADJR_R3 3             
   ADJR_RHI 3               ADJR_S1 3                ADJR_S2 3             
   ADJR_S3 3                ADJR_SHI 3               BASADR1 3             
   BASADR2 3                BASADR3 3                BASADRHI 3            
   BASER1 3                 BASER2 3                 BASER3 3              
   BASERHI 3                BASLNR1 3                BASLNR2 3             
   BASLNR3 3                BASLNRHI 3               ADJOFS1 3             
   ADJOFS2 3                ADJOFS3 3                ADJOFSHI 3            
   ADJS_B1 3                ADJS_B2 3                ADJS_B3 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_C3 3                ADJS_CHI 3               ADJS_D1 3             
   ADJS_D2 3                ADJS_D3 3                ADJS_DHI 3            
   ADJS_E1 3                ADJS_E2 3                ADJS_E3 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_F3 3                ADJS_FHI 3               ADJS_G1 3             
   ADJS_G2 3                ADJS_G3 3                ADJS_GHI 3            
   ADJS_H1 3                ADJS_H2 3                ADJS_H3 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_I3 3                ADJS_IHI 3               ADJS_J1 3             
   ADJS_J2 3                ADJS_J3 3                ADJS_JHI 3            
   ADJS_K1 3                ADJS_K2 3                ADJS_K3 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_L3 3                ADJS_LHI 3               ADJS_M1 3             
   ADJS_M2 3                ADJS_M3 3                ADJS_MHI 3            
   ADJS_N1 3                ADJS_N2 3                ADJS_N3 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_O3 3                ADJS_OHI 3               ADJS_P1 3             
   ADJS_P2 3                ADJS_P3 3                ADJS_PHI 3            
   ADJS_Q1 3                ADJS_Q2 3                ADJS_Q3 3             
   ADJS_QHI 3               ADJS_R1 3                ADJS_R2 3             
   ADJS_R3 3                ADJS_RHI 3               ADJS_S1 3             
   ADJS_S2 3                ADJS_S3 3                ADJS_SHI 3            
   BASADS1 3                BASADS2 3                BASADS3 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASES3 3                 BASESHI 3                BASLNS1 3             
   BASLNS2 3                BASLNS3 3                BASLNSHI 3            
   ADJOFC1 3                ADJOFC2 3                ADJOFC3 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_B3 3                ADJC_BHI 3               ADJC_C1 3             
   ADJC_C2 3                ADJC_C3 3                ADJC_CHI 3            
   ADJC_D1 3                ADJC_D2 3                ADJC_D3 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_E3 3                ADJC_EHI 3               ADJC_F1 3             
   ADJC_F2 3                ADJC_F3 3                ADJC_FHI 3            
   ADJC_G1 3                ADJC_G2 3                ADJC_G3 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_H3 3                ADJC_HHI 3               ADJC_I1 3             
   ADJC_I2 3                ADJC_I3 3                ADJC_IHI 3            
   ADJC_J1 3                ADJC_J2 3                ADJC_J3 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_K3 3                ADJC_KHI 3               ADJC_L1 3             
   ADJC_L2 3                ADJC_L3 3                ADJC_LHI 3            
   ADJC_M1 3                ADJC_M2 3                ADJC_M3 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_N3 3                ADJC_NHI 3               ADJC_O1 3             
   ADJC_O2 3                ADJC_O3 3                ADJC_OHI 3            
   ADJC_P1 3                ADJC_P2 3                ADJC_P3 3             
   ADJC_PHI 3               ADJC_Q1 3                ADJC_Q2 3             
   ADJC_Q3 3                ADJC_QHI 3               ADJC_R1 3             
   ADJC_R2 3                ADJC_R3 3                ADJC_RHI 3            
   ADJC_S1 3                ADJC_S2 3                ADJC_S3 3             
   ADJC_SHI 3               BASADC1 3                BASADC2 3             
   BASADC3 3                BASADCHI 3               BASEC1 3              
   BASEC2 3                 BASEC3 3                 BASECHI 3             
   BASLNC1 3                BASLNC2 3                BASLNC3 3             
   BASLNCHI 3               ADJOFU1 3                ADJOFU2 3             
   ADJOFU3 3                ADJOFUHI 3               ADJU_B1 3             
   ADJU_B2 3                ADJU_B3 3                ADJU_BHI 3            
   ADJU_C1 3                ADJU_C2 3                ADJU_C3 3             
   ADJU_CHI 3               ADJU_D1 3                ADJU_D2 3             
   ADJU_D3 3                ADJU_DHI 3               ADJU_E1 3             
   ADJU_E2 3                ADJU_E3 3                ADJU_EHI 3            
   ADJU_F1 3                ADJU_F2 3                ADJU_F3 3             
   ADJU_FHI 3               ADJU_G1 3                ADJU_G2 3             
   ADJU_G3 3                ADJU_GHI 3               ADJU_H1 3             
   ADJU_H2 3                ADJU_H3 3                ADJU_HHI 3            
   ADJU_I1 3                ADJU_I2 3                ADJU_I3 3             
   ADJU_IHI 3               ADJU_J1 3                ADJU_J2 3             
   ADJU_J3 3                ADJU_JHI 3               ADJU_K1 3             
   ADJU_K2 3                ADJU_K3 3                ADJU_KHI 3            
   ADJU_L1 3                ADJU_L2 3                ADJU_L3 3             
   ADJU_LHI 3               ADJU_M1 3                ADJU_M2 3             
   ADJU_M3 3                ADJU_MHI 3               ADJU_N1 3             
   ADJU_N2 3                ADJU_N3 3                ADJU_NHI 3            
   ADJU_O1 3                ADJU_O2 3                ADJU_O3 3             
   ADJU_OHI 3               ADJU_P1 3                ADJU_P2 3             
   ADJU_P3 3                ADJU_PHI 3               ADJU_Q1 3             
   ADJU_Q2 3                ADJU_Q3 3                ADJU_QHI 3            
   ADJU_R1 3                ADJU_R2 3                ADJU_R3 3             
   ADJU_RHI 3               ADJU_S1 3                ADJU_S2 3             
   ADJU_S3 3                ADJU_SHI 3               BASADU1 3             
   BASADU2 3                BASADU3 3                BASADUHI 3            
   BASEU1 3                 BASEU2 3                 BASEU3 3              
   BASEUHI 3                BASLNU1 3                BASLNU2 3             
   BASLNU3 3                BASLNUHI 3               SMAX1 6               
   SMAX2 6                  SMAX3 6                  SMAX4 6               
   SMAX5 6                  SMAX6 6                  SMAX7 6               
   SMAX8 6                  SMAX9 6                  SMAX10 6              
   SMAX11 6                 SMAX12 6                 SMAX13 6              
   SMAX14 6                 SMAX15 6                 SMAX16 6              
   SMAX17 6                 SMAX18 6                 SMAX19 6              
   SMAX20 6                 SMAX21 6                 SMAX22 6              
   SMAX23 6                 SMAX24 6                 SMAX25 6              
   SMAX26 6                 SMAX27 6                 SMAX28 6              
   SMAX29 6                 SMAX30 6                 SMAX31 6              
   SMAX32 4                 SMIN1 4                  SMIN2 4               
   SMIN3 4                  SMIN4 4                  SMIN5 4               
   SMIN6 4                  SMIN7 4                  SMIN8 4               
   SMIN9 4                  SMIN10 4                 SMIN11 4              
   SMIN12 4                 SMIN13 4                 SMIN14 4              
   SMIN15 4                 SMIN16 4                 SMIN17 4              
   SMIN18 4                 SMIN19 4                 SMIN20 4              
   SMIN21 4                 SMIN22 4                 SMIN23 4              
   SMIN24 4                 SMIN25 4                 SMIN26 3              
   SMIN27 3                 SMIN28 3                 SMIN29 3              
   SMIN30 3                 SMIN31 3                 SMIN32 3              
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCAT3 3               
   LCATHI 3                 LCATS1 3                 LCATS2 3              
   LCATS3 3                 LCATSHI 3                LCATR1 3              
   LCATR2 3                 LCATR3 3                 LCATRHI 3             
   LCATC1 3                 LCATC2 3                 LCATC3 3              
   LCATCHI 3                LCATU1 3                 LCATU2 3              
   LCATU3 3                 LCATUHI 3 ;

         

RUN ;
